invariant_list library
Provide an extension type IList as a replacement for the built-in class List as a type, with better type safety.
Extensions
-
IListExtension
on List<
T> - Extension methods used with regular List objects in order to concisely obtain an expression of type IList, and in order to validate the invariance.